Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(21)

Unified Diff: webrtc/modules/rtp_rtcp/include/rtp_rtcp.h

Issue 2545753002: Deprecated SetAudioPacketSize from RTPSender and removed calls to it. (Closed)
Patch Set: constexpr; parentheses Created 4 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | webrtc/modules/rtp_rtcp/source/rtp_rtcp_impl.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: webrtc/modules/rtp_rtcp/include/rtp_rtcp.h
diff --git a/webrtc/modules/rtp_rtcp/include/rtp_rtcp.h b/webrtc/modules/rtp_rtcp/include/rtp_rtcp.h
index bb9e1f2959878b77886e45652e2e0c6eafd60b72..98442ad6bc7f06496fb0db8f095d528e4103f459 100644
--- a/webrtc/modules/rtp_rtcp/include/rtp_rtcp.h
+++ b/webrtc/modules/rtp_rtcp/include/rtp_rtcp.h
@@ -428,10 +428,11 @@ class RtpRtcp : public Module {
// Audio
// **************************************************************************
// Sets audio packet size, used to determine when it's time to send a DTMF
// packet in silence (CNG).
// Returns -1 on failure else 0.
- virtual int32_t SetAudioPacketSize(uint16_t packet_size_samples) = 0;
+ RTC_DEPRECATED virtual int32_t SetAudioPacketSize(
+ uint16_t packet_size_samples) = 0;
// Sends a TelephoneEvent tone using RFC 2833 (4733).
// Returns -1 on failure else 0.
« no previous file with comments | « no previous file | webrtc/modules/rtp_rtcp/source/rtp_rtcp_impl.h » ('j') | no next file with comments »
@@ -428,10 +428,11 @@ class RtpRtcp : public Module {
// Audio
// **************************************************************************
- // Sets audio packet size, used to determine when it's time to send a DTMF
- // packet in silence (CNG).
+ // This function is deprecated. It was previously used to determine when it
+ // was time to send a DTMF packet in silence (CNG).
// Returns -1 on failure else 0.

Powered by Google App Engine
This is Rietveld 408576698